@@ -2,4 +2,4 @@
 
 [ ! -d m4 ] && mkdir m4
 
-autoreconf -i -s -f
+autoreconf -i -s -f -v
