@@ -15,30 +15,34 @@
 
 
 typedef struct Clock {
-   // always start with area
-   Area area;
+	// always start with area
+	Area area;
 
-   config_color font;
-   int time1_posy;
-   int time2_posy;
+	Color font;
+	int time1_posy;
+	int time2_posy;
 } Clock;
 
 
 extern char *time1_format;
+extern char *time1_timezone;
 extern char *time2_format;
-extern struct timeval time_clock;
-extern int  time_precision;
+extern char *time2_timezone;
+extern char *time_tooltip_format;
+extern char *time_tooltip_timezone;
 extern PangoFontDescription *time1_font_desc;
 extern PangoFontDescription *time2_font_desc;
 extern char *clock_lclick_command;
 extern char *clock_rclick_command;
+extern int clock_enabled;
 
 
 // initialize clock : y position, precision, ...
 void init_clock();
-void init_precision();
+void init_clock_panel(void *panel);
+void cleanup_clock();
 
-void draw_clock (void *obj, cairo_t *c, int active);
+void draw_clock (void *obj, cairo_t *c);
 
 void resize_clock (void *obj);
 
